@@ -169,11 +169,7 @@ class MongoResultSerializer(ABC):
             existing["status"] = status.value
             for k, v in extra.items():
                 if k == "error_info" and v:
-                    self.result_data_store.put(
-                        v,
-                        filename=_error_info_filename(job_id),
-                        encoding="utf-8",
-                    )
+                    self.result_data_store.put(v, filename=_error_info_filename(job_id), encoding="utf-8")
                 else:
                     existing[k] = v
             self._save_raw_to_db(existing)
@@ -187,10 +183,12 @@ class MongoResultSerializer(ABC):
         status: JobStatus = JobStatus.PENDING,
         overrides: Optional[Dict] = None,
         mailto: str = "",
+        error_mailto: str = "",
         generate_pdf_output: bool = True,
         hide_code: bool = False,
         scheduler_job_id: Optional[str] = None,
         is_slideshow: bool = False,
+        email_subject: Optional[str] = None,
     ) -> None:
         """Call this when we are just starting a check. Saves a "pending" job into storage."""
         job_start_time = job_start_time or datetime.datetime.now()
@@ -202,6 +200,8 @@ class MongoResultSerializer(ABC):
             job_start_time=job_start_time,
             report_name=report_name,
             mailto=mailto,
+            error_mailto=error_mailto,
+            email_subject=email_subject,
             generate_pdf_output=generate_pdf_output,
             overrides=overrides or {},
             hide_code=hide_code,
@@ -224,9 +224,7 @@ class MongoResultSerializer(ABC):
                     filename=filename_func(notebook_result.job_id),
                     encoding="utf-8",
                 )
-        for json_attribute, filename_func in [
-            ("raw_ipynb_json", _raw_json_filename),
-        ]:
+        for json_attribute, filename_func in [("raw_ipynb_json", _raw_json_filename)]:
             if getattr(notebook_result, json_attribute, None):
                 self.result_data_store.put(
                     json.dumps(getattr(notebook_result, json_attribute)),
@@ -299,10 +297,12 @@ class MongoResultSerializer(ABC):
                 generate_pdf_output=result.get("generate_pdf_output", True),
                 report_title=result.get("report_title", result["report_name"]),
                 mailto=result.get("mailto", ""),
+                error_mailto=result.get("error_mailto", ""),
                 hide_code=result.get("hide_code", False),
                 stdout=result.get("stdout", []),
                 scheduler_job_id=result.get("scheduler_job_id", None),
                 is_slideshow=result.get("is_slideshow", False),
+                email_subject=result.get("email_subject", None),
             )
         elif cls == NotebookResultPending:
             return NotebookResultPending(
@@ -315,6 +315,8 @@ class MongoResultSerializer(ABC):
                 generate_pdf_output=result.get("generate_pdf_output", True),
                 report_title=result.get("report_title", result["report_name"]),
                 mailto=result.get("mailto", ""),
+                error_mailto=result.get("error_mailto", ""),
+                email_subject=result.get("email_subject", ""),
                 hide_code=result.get("hide_code", False),
                 stdout=result.get("stdout", []),
                 scheduler_job_id=result.get("scheduler_job_id", None),
@@ -338,6 +340,8 @@ class MongoResultSerializer(ABC):
                 generate_pdf_output=result.get("generate_pdf_output", True),
                 report_title=result.get("report_title", result["report_name"]),
                 mailto=result.get("mailto", ""),
+                error_mailto=result.get("error_mailto", ""),
+                email_subject=result.get("email_subject", ""),
                 hide_code=result.get("hide_code", False),
                 stdout=result.get("stdout", []),
                 scheduler_job_id=result.get("scheduler_job_id", False),
@@ -367,10 +371,11 @@ class MongoResultSerializer(ABC):
             # pymongo<3.7 compat
             return self.library.count(base_filter)
 
-    def get_count_and_latest_time_per_report(self):
+    def get_count_and_latest_time_per_report(self, subfolder: Optional[str]):
+        base_filer = {} if not subfolder else {"report_name": {"$regex": subfolder + ".*"}}
         reports = list(
             self._get_raw_results(
-                base_filter={},
+                base_filter=base_filer,
                 projection={"report_name": 1, "job_start_time": 1, "scheduler_job_id": 1, "_id": 0},
                 limit=0,
             )
